==> tmgmt_smartling-8.x-2.11.tar.gz: tmgmt_smartling/src/Tests/SmartlingTestBase.php <==
<?php

namespace Drupal\tmgmt_smartling\Tests;

use Drupal;
use Drupal\node\Entity\Node;
use Drupal\tmgmt\Entity\Job;
use Drupal\tmgmt\JobInterface;
use Drupal\tmgmt\Tests\TMGMTTestBase;
use Smartling\Exceptions\SmartlingApiException;

/**
 * Basic tests for the Smartling translator.
 */
abstract class SmartlingTestBase extends TMGMTTestBase {

  /**
   * Name of file that contains settings for test Smartling project.
   *
   * @var string
   */
  const SETTINGS_FILE_NAME = 'tmgmt_smartling.simpletest.settings.php';

  /**
   * Smartling test project settings.
   *
   * @var array
   */
  protected $smartlingPluginProviderSettings = [];

  /**
   * Modules to enable.
   *
   * @var array
   */
  public static $modules = [
    'tmgmt',
    'tmgmt_demo',
    'tmgmt_smartling',
    'tmgmt_smartling_context_debug',
    'tmgmt_smartling_test',
    'dblog',
  ];

  /**
   * @var int
   */
  protected $testNodeId = 3;

  /**
   * @var string
   */
  protected $testNodeTitle;

  /**
   * @var string
   */
  protected $testNodeBody;

  /**
   * @var string
   */
  protected $targetLanguage = 'fr';

  /**
   * @var string
   */
  protected $sourceLanguage = 'en';

  /**
   * {@inheritdoc}
   */
  public function setUp() {
    parent::setUp();

    $settings_file_path = __DIR__ . '/../../' . self::SETTINGS_FILE_NAME;

    // Include settings from external file.
    if (file_exists($settings_file_path) && empty($this->smartlingPluginProviderSettings)) {
      require_once $settings_file_path;

      // Fetch needed data.
      $this->smartlingPluginProviderSettings = $settings;
      $test_node = Node::load($this->testNodeId);
      $this->testNodeTitle = $test_node->get('title')->value;
      $this->testNodeBody = trim(strip_tags($test_node->get('body')->value));
    }

    // Additional permission: access to "Recent log messages" page and
    // access for manual context sending.
    $this->loginAsAdmin([
      'access site reports',
      'send context smartling',
    ]);
  }

  /**
   * Invokes private/protected method.
   *
   * @param $object
   * @param $methodName
   * @param array $parameters
   *
   * @return mixed
   */
  protected function invokeMethod($object, $methodName, array $parameters = []) {
    $reflection = new \ReflectionClass(get_class($object));
    $method = $reflection->getMethod($methodName);
    $method->setAccessible(true);

    return $method->invokeArgs($object, $parameters);
  }

  /**
   * Removes test file from Smartling dashboard.
   *
   * @param $fileName
   */
  protected function deleteTestFile($fileName) {
    try {
      $api_factory = Drupal::service('tmgmt_smartling.smartling_api_factory');
      $smartlingApi = $api_factory::create([
        'user_id' => $this->smartlingPluginProviderSettings['settings[user_id]'],
        'project_id' => $this->smartlingPluginProviderSettings['settings[project_id]'],
        'token_secret' => $this->smartlingPluginProviderSettings['settings[token_secret]'],
      ], 'file');
      $smartlingApi->deleteFile($fileName);
    }
    catch (SmartlingApiException $e) {
      // File not found.
    }
  }

  /**
   * Sets up Smartling provider settings and returns translator plugin.
   *
   * @param array $providerSettings
   *
   * @return \Drupal\tmgmt\TranslatorInterface
   */
  protected function setUpSmartlingProviderSettings(array $providerSettings) {
    $translator = $this->createTranslator([
      'plugin' => 'smartling',
      'auto_accept' => $providerSettings['auto_accept'],
      'settings' => [
        'project_id' => $providerSettings['settings[project_id]'],
        'user_id' => $providerSettings['settings[user_id]'],
        'token_secret' => $providerSettings['settings[token_secret]'],
        'contextUsername' => $providerSettings['settings[contextUsername]'],
        'context_silent_user_switching' => $providerSettings['settings[context_silent_user_switching]'],
        'retrieval_type' => $providerSettings['settings[retrieval_type]'],
        'auto_authorize_locales' => $providerSettings['settings[auto_authorize_locales]'],
        'callback_url_use' => $providerSettings['settings[callback_url_use]'],
        'callback_url_host' => $providerSettings['settings[callback_url_host]'],
        'scheme' => $providerSettings['settings[scheme]'],
        'custom_regexp_placeholder' => $providerSettings['settings[custom_regexp_placeholder]'],
        'export_format' => $providerSettings['settings[export_format]'],
      ],
    ]);

    return $translator;
  }

  /**
   * Requests translation for a given node.
   *
   * @param $nid
   * @param $language
   * @param $translator
   *
   * @return \Drupal\tmgmt\JobInterface
   */
  protected function requestTranslationForNode($nid, $language, $translator) {
    $job = $this->createJob($this->sourceLanguage, $language, 1, [
      'label' => 'Job for ' . $nid,
      'job_type' => Job::TYPE_NORMAL,
    ]);
    $job->translator = $translator;
    $job->addItem('content', 'node', $nid);
    $job->setState(JobInterface::STATE_ACTIVE);
    $job->requestTranslation();

    return $job;
  }

  /**
   * Checks if generated file exists and correct.
   *
   * @param $fileName
   * @param $nodeTitle
   */
  protected function checkGeneratedFile($fileName, $nodeTitle) {
    $url = \Drupal::service('stream_wrapper_manager')->getViaUri(file_default_scheme() . "://tmgmt_sources/$fileName")->getExternalUrl();
    $this->drupalGet($url);
    $this->assertResponse(200);
    $this->assertRaw($nodeTitle);
  }

  /**
   * Checks if download was successful.
   *
   * @param $jobId
   * @param $fileName
   * @throws \Exception
   */
  protected function downloadAndCheckTranslatedFile($jobId, $fileName) {
    $this->drupalPostForm("admin/tmgmt/jobs/$jobId", [], t('Download'));
    $this->drupalGet('admin/reports/dblog');
    $this->assertResponse(200);
    // TODO: don't know why assertLink and assertRaw doesn't work with quoted
    // strings.
    $this->assertRaw('Translation for');
    $this->assertRaw($fileName);
    $this->assertRaw('was successfully downloaded and imported.');
  }

}

==> tmgmt_smartling-8.x-3.0.tar.gz: tmgmt_smartling/src/Tests/SmartlingTestBase.php <==
<?php

namespace Drupal\tmgmt_smartling\Tests;

use Drupal;
use Drupal\Core\Queue\RequeueException;
use Drupal\Core\Queue\SuspendQueueException;
use Drupal\node\Entity\Node;
use Drupal\tmgmt\Entity\Job;
use Drupal\tmgmt\JobInterface;
use Drupal\tmgmt\Tests\TMGMTTestBase;
use Smartling\Exceptions\SmartlingApiException;

/**
 * Basic tests for the Smartling translator.
 */
abstract class SmartlingTestBase extends TMGMTTestBase {

  /**
   * Name of file that contains settings for test Smartling project.
   *
   * @var string
   */
  const SETTINGS_FILE_NAME = 'tmgmt_smartling.simpletest.settings.php';

  /**
   * Smartling test project settings.
   *
   * @var array
   */
  protected $smartlingPluginProviderSettings = [];

  /**
   * Modules to enable.
   *
   * @var array
   */
  public static $modules = [
    'tmgmt',
    'tmgmt_demo',
    'tmgmt_smartling',
    'tmgmt_smartling_context_debug',
    'tmgmt_smartling_test',
    'dblog',
  ];

  /**
   * @var int
   */
  protected $testNodeId = 3;

  /**
   * @var string
   */
  protected $testNodeTitle;

  /**
   * @var string
   */
  protected $testNodeBody;

  /**
   * @var string
   */
  protected $targetLanguage = 'fr';

  /**
   * @var string
   */
  protected $sourceLanguage = 'en';

  /**
   * {@inheritdoc}
   */
  public function setUp() {
    parent::setUp();

    $settings_file_path = __DIR__ . '/../../' . self::SETTINGS_FILE_NAME;

    // Include settings from external file.
    if (file_exists($settings_file_path) && empty($this->smartlingPluginProviderSettings)) {
      require_once $settings_file_path;

      // Fetch needed data.
      $this->smartlingPluginProviderSettings = $settings;
      $test_node = Node::load($this->testNodeId);
      $this->testNodeTitle = $test_node->get('title')->value;
      $this->testNodeBody = trim(strip_tags($test_node->get('body')->value));
    }

    // Additional permission: access to "Recent log messages" page and
    // access for manual context sending.
    $this->loginAsAdmin([
      'access site reports',
      'send context smartling',
    ]);
  }

  /**
   * Invokes private/protected method.
   *
   * @param $object
   * @param $methodName
   * @param array $parameters
   *
   * @return mixed
   */
  protected function invokeMethod($object, $methodName, array $parameters = []) {
    $reflection = new \ReflectionClass(get_class($object));
    $method = $reflection->getMethod($methodName);
    $method->setAccessible(true);

    return $method->invokeArgs($object, $parameters);
  }

  /**
   * Removes test file from Smartling dashboard.
   *
   * @param $fileName
   */
  protected function deleteTestFile($fileName) {
    try {
      $api_factory = Drupal::service('tmgmt_smartling.smartling_api_factory');
      $smartlingApi = $api_factory::create([
        'user_id' => $this->smartlingPluginProviderSettings['settings[user_id]'],
        'project_id' => $this->smartlingPluginProviderSettings['settings[project_id]'],
        'token_secret' => $this->smartlingPluginProviderSettings['settings[token_secret]'],
      ], 'file');
      $smartlingApi->deleteFile($fileName);
    }
    catch (SmartlingApiException $e) {
      // File not found.
    }
  }

  /**
   * Sets up Smartling provider settings and returns translator plugin.
   *
   * @param array $providerSettings
   *
   * @return \Drupal\tmgmt\TranslatorInterface
   */
  protected function setUpSmartlingProviderSettings(array $providerSettings) {
    $translator = $this->createTranslator([
      'plugin' => 'smartling',
      'auto_accept' => $providerSettings['auto_accept'],
      'settings' => [
        'project_id' => $providerSettings['settings[project_id]'],
        'user_id' => $providerSettings['settings[user_id]'],
        'token_secret' => $providerSettings['settings[token_secret]'],
        'contextUsername' => $providerSettings['settings[contextUsername]'],
        'context_silent_user_switching' => $providerSettings['settings[context_silent_user_switching]'],
        'retrieval_type' => $providerSettings['settings[retrieval_type]'],
        'auto_authorize_locales' => $providerSettings['settings[auto_authorize_locales]'],
        'callback_url_use' => $providerSettings['settings[callback_url_use]'],
        'callback_url_host' => $providerSettings['settings[callback_url_host]'],
        'scheme' => $providerSettings['settings[scheme]'],
        'custom_regexp_placeholder' => $providerSettings['settings[custom_regexp_placeholder]'],
        'export_format' => $providerSettings['settings[export_format]'],
      ],
    ]);

    return $translator;
  }

  /**
   * Requests translation for a given node.
   *
   * @param $nid
   * @param $language
   * @param $translator
   *
   * @return \Drupal\tmgmt\JobInterface
   */
  protected function requestTranslationForNode($nid, $language, $translator) {
    $api_wrapper = $translator->getPlugin()->getApiWrapper($translator->getSettings());
    $job_id = $api_wrapper->createJob('Drupal TMGMT connector test ' . mt_rand(), '');
    $batch_uid = $api_wrapper->createBatch($job_id, FALSE);

    $job = $this->createJob($this->sourceLanguage, $language, 1, [
      'label' => 'Job for ' . $nid,
      'job_type' => Job::TYPE_NORMAL,
    ]);
    $job->set('settings', [
      'batch_uid' => $batch_uid,
      'batch_execute_on_job' => $job->id(),
    ]);
    $job->translator = $translator;
    $job->addItem('content', 'node', $nid);
    $job->setState(JobInterface::STATE_ACTIVE);
    $job->requestTranslation();

    $api_wrapper->cancelJob($job_id);

    return $job;
  }

  /**
   * Checks if generated file exists and correct.
   *
   * @param $fileName
   * @param $nodeTitle
   * @param string $format
   */
  protected function checkGeneratedFile($fileName, $nodeTitle, $format = 'xml') {
    $file_path = \Drupal::getContainer()->get('file_system')->realpath(file_default_scheme() . "://tmgmt_sources/$fileName");
    $content = file_get_contents($file_path);

    $this->assertTrue(strpos($content, $nodeTitle) !== FALSE, 'Title is in file');

    $no_directives = $format != 'xml';

    $this->assertTrue(strpos($content, '<!-- smartling.variants_enabled = true -->') !== $no_directives);
    $this->assertTrue(strpos($content, '<!-- smartling.source_key_paths = html/body/div/{div.sl-variant}, html/body/div/{span.sl-variant} -->') !== $no_directives);
    $this->assertTrue(strpos($content, '<span sl-variant="node-3-title][0][value" class="atom" id="bMV1bdGl0bGVdWzBdW3ZhbHVl">') !== $no_directives);
    $this->assertTrue(strpos($content, '<div sl-variant="node-3-body][0][value" class="atom" id="bMV1bYm9keV1bMF1bdmFsdWU">') !== $no_directives);
  }

  /**
   * Checks if download was successful.
   *
   * @param $jobId
   * @param $fileName
   * @throws \Exception
   */
  protected function downloadAndCheckTranslatedFile($jobId, $fileName) {
    $this->drupalPostForm("admin/tmgmt/jobs/$jobId", [], t('Download'));
    $this->drupalGet('admin/reports/dblog');
    $this->assertResponse(200);
    // TODO: don't know why assertLink and assertRaw doesn't work with quoted
    // strings.
    $this->assertRaw('Translation for');
    $this->assertRaw($fileName);
    $this->assertRaw('was successfully downloaded and imported.');
  }

  /**
   * Returns amount of items in a given queue.
   *
   * @param string $queueName
   *
   * @return mixed
   */
  protected function getCountOfItemsInQueue($queueName) {
    return Drupal::database()->select('queue', 'q')
      ->condition('q.name', $queueName)
      ->countQuery()
      ->execute()
      ->fetchField();
  }

  /**
   * Processes cron queue.
   * @param $name
   */
  protected function processQueue($name) {
    $queue_factory = Drupal::service('queue');
    $queue_manager = Drupal::service('plugin.manager.queue_worker');

    // Grab the defined cron queues.
    foreach ($queue_manager->getDefinitions() as $queue_name => $info) {
      if ($queue_name != $name) {
        continue;
      }

      if (isset($info['cron'])) {
        // Make sure every queue exists. There is no harm in trying to recreate
        // an existing queue.
        $queue_factory->get($queue_name)->createQueue();

        $queue_worker = $queue_manager->createInstance($queue_name);
        $end = time() + (isset($info['cron']['time']) ? $info['cron']['time'] : 15);
        $queue = $queue_factory->get($queue_name);
        $lease_time = isset($info['cron']['time']) ?: NULL;
        while (time() < $end && ($item = $queue->claimItem($lease_time))) {
          try {
            $queue_worker->processItem($item->data);
            $queue->deleteItem($item);
          }
          catch (RequeueException $e) {
            // The worker requested the task be immediately requeued.
            $queue->releaseItem($item);
          }
          catch (SuspendQueueException $e) {
            // If the worker indicates there is a problem with the whole queue,
            // release the item and skip to the next queue.
            $queue->releaseItem($item);

            watchdog_exception('cron', $e);

            // Skip to the next queue.
            continue 2;
          }
          catch (\Exception $e) {
            // In case of any other kind of exception, log it and leave the item
            // in the queue to be processed again later.
            watchdog_exception('cron', $e);
          }
        }
      }
    }
  }

}
